==> tim_ui_kit-0.0.3.tar.gz: lib/ui/views/TIMUIKitSearch/pureUI/tim_uikit_search_showAll.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tim_ui_kit/tim_ui_kit.dart';
import 'package:tim_ui_kit/ui/utils/color.dart';

import 'package:tim_ui_kit/business_logic/view_models/tui_theme_view_model.dart';

class TIMUIKitSearchShowALl extends StatelessWidget {
  final String textShow;
  final VoidCallback? onClick;

  const TIMUIKitSearchShowALl({Key? key,
    this.onClick, required this.textShow}) : super(key: key);

  _renderLineOneRight(String? text, TUITheme theme){
    if(text != null){
      return Text(text,
          style: TextStyle(
            fontSize: 12,
            color: theme.weakTextColor,
          ));
    }else{
      return Container();
    }
  }

  _renderLineTwo(String? text, TUITheme theme){
    return (text != null) ?
    Text(
      text,
      style: TextStyle(color: theme.weakTextColor, height: 1.5, fontSize: 14),
    ) : Container(height: 0,);
  }


  @override
  Widget build(BuildContext context) {
    final theme = Provider.of<TUIThemeViewModel>(context).theme;
    return GestureDetector(
      onTap: onClick,
      child: Container(
        decoration: BoxDecoration(
          color: Colors.white,
            border: Border(bottom: BorderSide(color: hexToColor("DBDBDB"), width: 0.5))
        ),
        padding: const EdgeInsets.fromLTRB(16, 8, 16, 8),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Icon(
              Icons.search,
              color: hexToColor("979797"),
            ),
            Expanded(
                child: Container(
                  margin: const EdgeInsets.only(left: 12),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Container(
                        // height: 24,
                        padding: const EdgeInsets.symmetric(vertical: 2),
                        child: Text(
                          textShow,
                          style: const TextStyle(
                              color: Colors.black,
                              fontSize: 18.0,
                              fontWeight: FontWeight.w400),
                        ),
                      ),
                    ],
                  ),
                )
            ),
            Icon(
              Icons.expand_more,
              color: hexToColor("979797"),
            ),
          ],
        ),
      ),
    );
  }
}

==> tim_ui_kit-0.0.5.tar.gz: lib/ui/views/TIMUIKitSearch/pureUI/tim_uikit_search_showAll.dart <==
import 'package:flutter/material.dart';
import 'package:tim_ui_kit/ui/utils/color.dart';


class TIMUIKitSearchShowALl extends StatelessWidget {
  final String textShow;
  final VoidCallback? onClick;
  final bool isNeedMoreBottom;

  const TIMUIKitSearchShowALl({Key? key,
    this.onClick, required this.textShow,
    this.isNeedMoreBottom = false}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onClick,
      child: Container(
        decoration: BoxDecoration(
          color: Colors.white,
            border: Border(bottom: BorderSide(color: hexToColor("DBDBDB"), width: 0.5))
        ),
        padding: EdgeInsets.fromLTRB(0, 8, 0, (isNeedMoreBottom ? 24 : 8)),
        child: Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Icon(
              Icons.search,
              color: hexToColor("979797"),
            ),
            Expanded(
                child: Container(
                  margin: const EdgeInsets.only(left: 12),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Container(
                        // height: 24,
                        padding: const EdgeInsets.symmetric(vertical: 2),
                        child: Text(
                          textShow,
                          style: const TextStyle(
                              color: Colors.black,
                              fontSize: 16.0,
                              fontWeight: FontWeight.w400),
                        ),
                      ),
                    ],
                  ),
                )
            ),
            Icon(
              Icons.expand_more,
              color: hexToColor("979797"),
            ),
          ],
        ),
      ),
    );
  }
}
